summaryrefslogtreecommitdiff
path: root/nuttx/drivers/usbhost
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-31 17:26:36 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-31 17:26:36 -0600
commit39c90ce1ce01a0b45451df19c1635240d47aaf29 (patch)
tree3814c0a5ce1961e161e268801e0529a926100ffb /nuttx/drivers/usbhost
parente4f3869daedaf22dd224285cc7f0373e0a5025d2 (diff)
downloadpx4-nuttx-39c90ce1ce01a0b45451df19c1635240d47aaf29.tar.gz
px4-nuttx-39c90ce1ce01a0b45451df19c1635240d47aaf29.tar.bz2
px4-nuttx-39c90ce1ce01a0b45451df19c1635240d47aaf29.zip
Rename kmalloc to kmm_malloc for consistency
Diffstat (limited to 'nuttx/drivers/usbhost')
-rwxr-xr-xnuttx/drivers/usbhost/usbhost_devaddr.c2
-rw-r--r--nuttx/drivers/usbhost/usbhost_hidkbd.c2
-rw-r--r--nuttx/drivers/usbhost/usbhost_hidmouse.c2
-rw-r--r--nuttx/drivers/usbhost/usbhost_skeleton.c2
-rw-r--r--nuttx/drivers/usbhost/usbhost_storage.c6
5 files changed, 7 insertions, 7 deletions
diff --git a/nuttx/drivers/usbhost/usbhost_devaddr.c b/nuttx/drivers/usbhost/usbhost_devaddr.c
index e4bd67922..24eb63556 100755
--- a/nuttx/drivers/usbhost/usbhost_devaddr.c
+++ b/nuttx/drivers/usbhost/usbhost_devaddr.c
@@ -196,7 +196,7 @@ int usbhost_devaddr_create(FAR struct usbhost_devaddr_s *hcd,
/* Allocate a hash table entry */
- hentry = (FAR struct usbhost_devhash_s *)kmalloc(sizeof(struct usbhost_devhash_s));
+ hentry = (FAR struct usbhost_devhash_s *)kmm_malloc(sizeof(struct usbhost_devhash_s));
if (!hentry)
{
udbg("ERROR: Failed to allocate a hash table entry\n");
diff --git a/nuttx/drivers/usbhost/usbhost_hidkbd.c b/nuttx/drivers/usbhost/usbhost_hidkbd.c
index b18399e38..763c3151c 100644
--- a/nuttx/drivers/usbhost/usbhost_hidkbd.c
+++ b/nuttx/drivers/usbhost/usbhost_hidkbd.c
@@ -664,7 +664,7 @@ static inline FAR struct usbhost_state_s *usbhost_allocclass(void)
FAR struct usbhost_state_s *priv;
DEBUGASSERT(!up_interrupt_context());
- priv = (FAR struct usbhost_state_s *)kmalloc(sizeof(struct usbhost_state_s));
+ priv = (FAR struct usbhost_state_s *)kmm_malloc(sizeof(struct usbhost_state_s));
uvdbg("Allocated: %p\n", priv);;
return priv;
}
diff --git a/nuttx/drivers/usbhost/usbhost_hidmouse.c b/nuttx/drivers/usbhost/usbhost_hidmouse.c
index 3d5752941..5fdf181fa 100644
--- a/nuttx/drivers/usbhost/usbhost_hidmouse.c
+++ b/nuttx/drivers/usbhost/usbhost_hidmouse.c
@@ -519,7 +519,7 @@ static inline FAR struct usbhost_state_s *usbhost_allocclass(void)
FAR struct usbhost_state_s *priv;
DEBUGASSERT(!up_interrupt_context());
- priv = (FAR struct usbhost_state_s *)kmalloc(sizeof(struct usbhost_state_s));
+ priv = (FAR struct usbhost_state_s *)kmm_malloc(sizeof(struct usbhost_state_s));
uvdbg("Allocated: %p\n", priv);;
return priv;
}
diff --git a/nuttx/drivers/usbhost/usbhost_skeleton.c b/nuttx/drivers/usbhost/usbhost_skeleton.c
index 028441b72..b1af20f11 100644
--- a/nuttx/drivers/usbhost/usbhost_skeleton.c
+++ b/nuttx/drivers/usbhost/usbhost_skeleton.c
@@ -253,7 +253,7 @@ static inline FAR struct usbhost_state_s *usbhost_allocclass(void)
FAR struct usbhost_state_s *priv;
DEBUGASSERT(!up_interrupt_context());
- priv = (FAR struct usbhost_state_s *)kmalloc(sizeof(struct usbhost_state_s));
+ priv = (FAR struct usbhost_state_s *)kmm_malloc(sizeof(struct usbhost_state_s));
uvdbg("Allocated: %p\n", priv);;
return priv;
}
diff --git a/nuttx/drivers/usbhost/usbhost_storage.c b/nuttx/drivers/usbhost/usbhost_storage.c
index a3ff5ed4f..0b8072467 100644
--- a/nuttx/drivers/usbhost/usbhost_storage.c
+++ b/nuttx/drivers/usbhost/usbhost_storage.c
@@ -74,7 +74,7 @@
#endif
/* If the create() method is called by the USB host device driver from an
* interrupt handler, then it will be unable to call kmalloc() in order to
* allocate a new class instance. If the create() method is called from the
* interrupt level, then class instances must be pre-allocated.
*/
@@ -388,11 +388,11 @@ static inline FAR struct usbhost_state_s *usbhost_allocclass(void)
FAR struct usbhost_state_s *priv;
/* We are not executing from an interrupt handler so we can just call
- * kmalloc() to get memory for the class instance.
+ * kmm_malloc() to get memory for the class instance.
*/
DEBUGASSERT(!up_interrupt_context());
- priv = (FAR struct usbhost_state_s *)kmalloc(sizeof(struct usbhost_state_s));
+ priv = (FAR struct usbhost_state_s *)kmm_malloc(sizeof(struct usbhost_state_s));
uvdbg("Allocated: %p\n", priv);;
return priv;
}
@@ -74,7 +74,7 @@
#endif
/* If the create() method is called by the USB host device driver from an
- * interrupt handler, then it will be unable to call kmalloc() in order to
+ * interrupt handler, then it will be unable to call kmm_malloc() in order to
* allocate a new class instance. If the create() method is called from the
* interrupt level, then class instances must be pre-allocated.